Unified protocol server lifecycle implementation Unified protocol server implementation for the SMTP mock server.
Structs
- Smtp
Mock Server - A
MockProtocolServerwrapper aroundSmtpServer.
Unified protocol server lifecycle implementation Unified protocol server implementation for the SMTP mock server.
MockProtocolServer wrapper around SmtpServer.